这个杀手不太冷 (豆瓣)
Description: 这个杀手不太冷电影简介和剧情介绍,这个杀手不太冷影评、图片、预告片、影讯、论坛、在线购票
Keywords: 这个杀手不太冷,Léon,这个杀手不太冷影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.5豆瓣电影Top250

# 这个杀手不太冷 Léon (1994)

更新描述或海报

导演: 吕克·贝松
编剧: 吕克·贝松
主演: 让·雷诺 / 娜塔莉·波特曼 / 加里·奥德曼 / 丹尼·爱罗 / 彼得·阿佩尔 / 迈克尔·巴达鲁科 / 艾伦·格里尼 / 伊丽莎白·瑞根 / 卡尔·马图斯维奇 / 弗兰克·赛格 / 麦温 / 乔治·马丁 / 罗伯特·拉萨多 / 亚当·布斯奇 / 马里奥·托迪斯科 / 萨米·纳塞利
类型: 剧情 / 动作 / 犯罪
制片国家/地区: 法国 / 美国
语言: 英语 / 意大利语 / 法语
上映日期: 1994-09-14(法国)
片长: 110分钟(剧场版) / 133分钟(国际版)
又名: 终极追杀令(台) / 杀手莱昂 / 杀手里昂 / Leon / Leon: The Professional
IMDb: tt0110413
豆瓣评分
引用
9.4
2195917人评价
5星
73.8%
4星
22.7%
3星
3.2%
2星
0.2%
1星
0.1%
好友评分
你关注的人看过这部作品的平均分
9.4
7人评价
好于 99% 剧情片
好于 99% 犯罪片
我看过这部电影 2020-07-12 修改
我的评价:
推荐

## 这个杀手不太冷的剧情简介 · · · · · ·

里昂（让·雷诺饰）是名孤独的职业杀手，受人雇佣。一天，邻居家小姑娘马蒂尔达（纳塔丽·波特曼饰)敲开他的房门，要求在他那里暂避杀身之祸。原来邻居家的主人是警方缉毒组的眼线，只因贪污了一小包毒品而遭恶警（加里·奥德曼饰）杀害全家的惩罚。马蒂尔达得到里昂的留救，幸免于难，并留在里昂那里。里昂教小女孩使枪，她教里昂法文，两人关系日趋亲密，相处融洽。
女孩想着去报仇，反倒被抓，里昂及时赶到，将女孩救回。混杂着哀怨情仇的正邪之战渐次升级，更大的冲突在所难免…… ©豆瓣

## 这个杀手不太冷的演职员 · · · · · · ( 全部 30 )

- 吕克·贝松 导演
- 让·雷诺 饰 莱昂 Léon
- 娜塔莉·波特曼 饰 马蒂尔达 Mathilda
- 加里·奥德曼 饰 斯坦斯菲尔德 Stansfield
- 丹尼·爱罗 饰 托尼 Tony
- 彼得·阿佩尔 饰 莫克 Malky

## 这个杀手不太冷的视频和图片 · · · · · · ( 预告片4 | 视频评论1 · 添加 | 图片2025 · 添加 )

## 这个杀手不太冷的获奖情况 · · · · · · ( 全部 )

- 第19届日本电影学院奖
- 最佳外语片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  罗马假日

  泰坦尼克号

  恋恋笔记本

  爱在黎明破晓前

  重庆森林

  剪刀手爱德华

  猫鼠游戏

  天使爱美丽

  怦然心动

  傲慢与偏见

我要写短评

## 这个杀手不太冷的短评 · · · · · · ( 全部 376735 条 )

热门 / 最新 / 好友

### 14737 有用 沉歌 看过 2007-10-14 15:39:36

萝莉有颗御姐心，正太有个大叔身——邪恶又天真、残酷又温柔，多完美~

### 8200 有用 能工巧匠沙门哥 看过 2007-08-16 10:52:43

一半的魅力来自反派：Gary Oldman.

### 8094 有用 眠去 看过 2007-02-10 10:52:10

她对Leon说，自从遇见你后，我的胃，再也不痛了……

### 2166 有用 瓶子不能倒 看过 2016-11-29 18:14:06

里昂只有一颗盆栽，不善言辞，爱喝牛奶。他不像，却真正是一个杀手。玛蒂达的到来，是包袱，也给里昂带来了生机。不过这种设定，注定是悲剧收场。里昂死后，玛蒂达将他盆栽的种子落地生根，里昂终于不再每日拿着手枪在椅子上不安地入睡，他落地了。娜塔莉波特曼太灵了，玛蒂达是如此特别。

### 5165 有用 看到了什么山 看过 2012-03-05 17:42:38

我没啥感觉的公认好片。

> 更多短评 376735条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。

### 0 有用 黑烟的圈 看过 2020-08-13 11:20:59

多话的女人和少言的男人是如此的合拍。

### 0 有用 CoCo陶可可 看过 2021-02-10 15:05:36

2021，005。He loved her.

我要写影评

## 这个杀手不太冷的影评 · · · · · · ( 全部 5964 条 )

热门 / 最新 / 好友
MercurioDong 2006-05-12 19:06:02

## 坚忍的魂与隐秘的梦

喝了些酒，光线很暗。最喜欢趁着这时候写东西，畅快淋漓。放着贝多芬的小提琴协奏曲。想起那个变态恶人说的：“贝多芬的开场很好，让我感觉非常爽，但是到后来，它就开始他妈的无聊。——知道我现在还不杀你的原因了么？”话说完，一阵乱扫之后，硕大的身躯倒地。一次屠杀完成... (展开)
5798 230 339回应 收起
jojosue 2009-01-03 10:32:23

## 我以保护的方式来爱你

我爱你，所以我不去吻你。我爱你，所以我对你冷言冷语。我爱你，所以我要你离开我，过你自己的生活。我爱你，所以我选择默默地保护着你。保护，是我爱你的方式。 这就是里昂对玛蒂尔的爱。鱼对飞鸟的爱，无法搁置。只有选择这样的方式去爱。爱得隐忍，爱得伤痛。 一个杀手不该... (展开)
3500 154 197回应 收起
孔乔 2005-10-05 22:27:19

## SHAPE OF MY HEART

这篇影评可能有剧透

题记：“这是关于两个小孩的故事，一个女孩和一个男孩，在他们心里，他们都是12岁，他们都感到失落而他们深爱彼此。” 　　　　　　　　　　　　　　　　　　　 ——吕克·贝松”  《Leon》。LucBesson的作品。 始终不明白为什么会翻译成如此古怪的一个中文片名。 ... (展开)
7746 542 420回应 收起
和菜头 2005-11-13 22:37:45

## 关于杀手

杀手是我们平淡无奇生活的一种补充，那是另外一种完全不同的生活状态。与之类似的单词还有海盗、间谍、猎人、流浪者。我一直觉得这些都是纯粹的男性职业，在这个男人也穿耳洞、着闪亮衣衫，雌雄莫辨的时代里，这几种人分明让人感觉得到一种原始的男性的魅力，雄性的力量。他们... (展开)
1375 189 125回应 收起
贝塔先生 2008-08-07 01:31:17

## 小萝莉与怪蜀黍阳光灿烂的日子

没人再有耐心读文字的时代 我想在每个周二晚十点，讲一个荒唐的故事，欢迎关注 －－－－－－－－－广告结束，我让路－－－－－－－－－－－ 1994年，娜塔莉波曼刚满13岁。这个双子座的活泼小萝莉在街上闲逛时，偶然被星探发现，继而被介绍给了吕克贝松。既然说是小萝莉，那么吕... (展开)
1693 425 219回应 收起
flashmind 2005-12-16 21:02:43

## 有关Leon

人的偏见有时候是很顽固的，两年前一帮朋友聚在一起看碟，xxtna几次推荐“这个杀手不太冷”我都没在意。港味十足的名字，一听是个动作片，心想就算拍得好又能怎样？我喜欢机智的对白和动人的情感。然后是大家云聚云散，我离开深圳回了家。一天在FTP服务器的丛林里找点东西，没... (展开)
784 39 74回应 收起
淡色桃花痕 2008-07-16 09:50:14

## 孤独是人类最大的杀手

观众们在看过无数部商业片后，总是会在影片刚放了开头的时候就精明地猜出结局。这就是商业片，一个按类型已经固定下来的内容模式。《LEON》作为一部商业片，自然也必须具备枪战片中的英雄和歹徒、正义和非正义的殊死搏斗，最后还必须是正义得以伸张。当然其中更不能缺少的... (展开)
766 29 42回应 收起
楚平 2011-01-04 10:26:49

## 假如马蒂达变成洛丽塔

“你说莱昂和马蒂达算不算恋爱呢？” 看完电影《这个杀手不太冷》，许多人都有这样的疑问吧。就像看完新版的《大侦探福尔摩斯》，大家也会揣摩一下，福尔摩斯和华生之间是否有奸情涌动。虽然导演并未对上述疑问给出一个明确的答案，但他们喜欢观众会产生这样“邪恶”的想法... (展开)
356 51 76回应 收起
三生白 2009-04-02 18:04:54

## 安

“这是关于两个小孩的故事，一个女孩和一个男孩，在他们心里，他们都是12岁，他们都感到失落而深爱彼此。”　　　　　　　　　　　　　　　 　——吕克·贝松 他是一个所谓的职业杀手，闲暇时，给心爱的植物喝水，独自看一场旧电影，傻笑。... (展开)
310 17 24回应 收起
思考的猫 2012-08-18 10:03:18

## 为生活开另一扇门

第一次看《这个杀手不太冷》是在6、7年前，时间太长，以至于最近看了导演剪辑版后，也不能搞清这版本多了哪些镜头。同样的电影，不同阶段看，可能感受也不同，几年前看电影时，还是个无忧无虑的学生，关注的是奥德曼如何坏的令人崇拜，主角莱昂何其生猛，一人敌过数十人，感觉... (展开)
253 15 22回应 收起

> 更多影评 5964篇

添加新讨论

## 讨论区 · · · · · ·

这部电影不值9.4分。 | 来自wknnndnn | 246 回应 | 2022-11-20 23:46:25
为什么中国拍不出来呢 | 来自缸中鱼 |  | 2022-11-20 13:21:58
所以现在还能到哪里看这部电影 | 来自豆友zne2DoDwXE | 3 回应 | 2022-11-19 00:58:43
变态警察吃的胶囊是什么药？ | 来自月豆豆 | 1 回应 | 2022-11-19 00:53:33
里昂 | 来自Catherine🌟 |  | 2022-11-18 14:02:35

> 去这部影片的讨论区（全部1255条）

## 关于《这个杀手不太冷》的问题 · · · · · · ( 全部81个 )

- 为什么总是一定要喝牛奶？ 15人回答
- 莱昂和玛蒂尔德之间是爱情吗？ 34人回答

> 全部81个问题

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 深情即是一桩悲剧，必得以死来句读。 (眠去)
- 【内牛满面】 (影志)
- 【你连名字都那么牛逼】 (狷介有乌青)
- 入选《第十放映室》影片之国外篇Ⅰ (心之旋影)

## 谁在看这部电影 · · · · · ·

- WANG
  刚刚 看过
- Guofy
  1分钟前 看过
- 千层度
  2分钟前 看过

3994846人看过 / 411323人想看

订阅这个杀手不太冷的评论:
feed: rss 2.0